package com.mortals.xhx.module.certificate.web;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.exception.AppException;
import com.mortals.xhx.module.certificate.model.CertificateCatalogEntity;
import com.mortals.xhx.module.certificate.model.CertificateCatalogQuery;
import com.mortals.xhx.module.certificate.pdu.ApplyLogPdu;
import com.mortals.xhx.module.certificate.pdu.CatalogVO;
import com.mortals.xhx.module.certificate.service.CertificateCatalogService;
import com.mortals.xhx.module.record.service.ApplyLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("api")
public class CertificateApi {

    @Autowired
    private CertificateCatalogService certificateCatalogService;
    @Autowired
    private ApplyLogService applyLogService;

    @PostMapping({"catalog/list"})
    @UnAuth
    public String getCatalogList(){

        JSONObject ret = new JSONObject();
        Map<String, Object> model = new HashMap();

        byte code = 1;
        try {
            List<CertificateCatalogEntity> list = certificateCatalogService.find(new CertificateCatalogQuery());
            List<CatalogVO> catalogList = new ArrayList<>();
            for(CertificateCatalogEntity entity:list){
                CatalogVO catalogVO = new CatalogVO(entity.getId(),entity.getCatalogName(),entity.getCatalogCode());
                JSONObject formContent = JSONObject.parseObject(entity.getFormContent());
                JSONArray formList = formContent.getJSONArray("list");
                JSONObject json = new JSONObject();
                for (int j = 0; j < formList.size(); j++) {
                    JSONObject jsonObject = formList.getJSONObject(j);
                    json.put(jsonObject.getString("id"),"");
                }
                catalogVO.setFormContent(json.toJSONString());

                catalogList.add(catalogVO);
            }
            model.put("message_info", "获取证照目录成功");
            ret.put("data", catalogList);
        }catch (Exception e){
            code = -1;
            model.put("message_info", "系统发生异常,请稍后再试");
        }
        ret.put("code",  Integer.valueOf(code));
        ret.put("msg", model.remove("message_info"));
        return ret.toJSONString();
    }

    @PostMapping({"certificate/submit"})
    @UnAuth
    public String postA(@RequestBody ApplyLogPdu applyLogPdu){
        JSONObject ret = new JSONObject();
        Map<String, Object> model = new HashMap();
        byte code = 1;
        try {
            applyLogService.apiSaveApplyLog(applyLogPdu);
            model.put("message_info", "生成证照成功");
        }catch (Exception e){
            code = -1;
            model.put("message_info", "生成证照发生异常");
            if(e instanceof AppException){
                model.put("message_info", e.getMessage());
            }
        }
        ret.put("code",  Integer.valueOf(code));
        ret.put("msg", model.remove("message_info"));
        return ret.toJSONString();
    }
}
